@@ -1,15 +1,15 @@
-// Copyright 2012-2021 David Robillard <d@drobilla.net>
+// Copyright 2012-2024 David Robillard <d@drobilla.net>
 // SPDX-License-Identifier: ISC
 
-#include "sratom/sratom.h"
+#include <sratom/sratom.h>
 
-#include "lv2/atom/atom.h"
-#include "lv2/atom/forge.h"
-#include "lv2/atom/util.h"
-#include "lv2/midi/midi.h"
-#include "lv2/urid/urid.h"
-#include "serd/serd.h"
-#include "sord/sord.h"
+#include <lv2/atom/atom.h>
+#include <lv2/atom/forge.h>
+#include <lv2/atom/util.h>
+#include <lv2/midi/midi.h>
+#include <lv2/urid/urid.h>
+#include <serd/serd.h>
+#include <sord/sord.h>
 
 #include <assert.h>
 #include <ctype.h>
@@ -107,7 +107,7 @@ sratom_set_sink(Sratom*           sratom,
     serd_node_free(&sratom->base_uri);
     sratom->base_uri =
       serd_node_new_uri_from_string(USTR(base_uri), NULL, NULL);
-    serd_uri_parse(sratom->base_uri.buf, &sratom->base);
+    serd_uri_parse((const uint8_t*)sratom->base_uri.buf, &sratom->base);
   }
   sratom->write_statement = sink;
   sratom->end_anon        = end_sink;
@@ -237,10 +237,12 @@ sratom_write(Sratom*         sratom,
              uint32_t        size,
              const void*     body)
 {
+  static const char hex_chars[] = "0123456789ABCDEF";
+
   const char* const type        = unmap->unmap(unmap->handle, type_urid);
-  uint8_t           idbuf[12]   = "b0000000000";
+  const uint8_t     idbuf[12]   = "b0000000000";
   SerdNode          id          = serd_node_from_string(SERD_BLANK, idbuf);
-  uint8_t           nodebuf[12] = "b0000000000";
+  const uint8_t     nodebuf[12] = "b0000000000";
   SerdNode          node        = serd_node_from_string(SERD_BLANK, nodebuf);
   SerdNode          object      = SERD_NODE_NULL;
   SerdNode          datatype    = SERD_NODE_NULL;
@@ -323,13 +325,12 @@ sratom_write(Sratom*         sratom,
     new_node = true;
     datatype = serd_node_from_string(SERD_URI, USTR(LV2_MIDI__MidiEvent));
 
-    const size_t   len = (size_t)size * 2U;
-    uint8_t* const str = (uint8_t*)calloc(len + 1, 1);
-    for (uint32_t i = 0; i < size; ++i) {
-      snprintf((char*)str + ((size_t)2 * i),
-               len - ((size_t)2 * i) + 1U,
-               "%02X",
-               (unsigned)*((const uint8_t*)body + i));
+    const size_t len = (size_t)size * 2U;
+    char* const  str = (char*)calloc(len + 1, 1);
+    for (size_t i = 0U; i < size; ++i) {
+      const uint8_t byte = ((const uint8_t*)body)[i];
+      str[2U * i]        = hex_chars[byte >> 4U];
+      str[2U * i + 1U]   = hex_chars[byte & 0x0FU];
     }
 
     object = serd_node_from_string(SERD_LITERAL, USTR(str));
@@ -452,7 +453,9 @@ sratom_write(Sratom*         sratom,
     start_object(sratom, &flags, subject, predicate, &id, type);
     SerdNode p = serd_node_from_string(SERD_URI, NS_RDF "value");
     flags |= SERD_LIST_O_BEGIN;
-    LV2_ATOM_SEQUENCE_BODY_FOREACH (seq, size, ev) {
+    for (const LV2_Atom_Event* ev = lv2_atom_sequence_begin(seq);
+         !lv2_atom_sequence_is_end(seq, size, ev);
+         ev = lv2_atom_sequence_next(ev)) {
       sratom->seq_unit = seq->unit;
       list_append(sratom,
                   unmap,
@@ -597,7 +600,7 @@ read_resource(Sratom*         sratom,
 }
 
 static uint32_t
-atom_size(Sratom* sratom, uint32_t type_urid)
+atom_size(const Sratom* sratom, uint32_t type_urid)
 {
   if (type_urid == sratom->forge.Int || type_urid == sratom->forge.Bool) {
     return sizeof(int32_t);
@@ -627,10 +630,10 @@ read_literal(Sratom* sratom, LV2_Atom_Forge* forge, const SordNode* node)
 {
   assert(sord_node_get_type(node) == SORD_LITERAL);
 
-  size_t      len      = 0;
-  const char* str      = (const char*)sord_node_get_string_counted(node, &len);
-  SordNode*   datatype = sord_node_get_datatype(node);
-  const char* language = sord_node_get_language(node);
+  size_t          len = 0;
+  const char*     str = (const char*)sord_node_get_string_counted(node, &len);
+  const SordNode* datatype = sord_node_get_datatype(node);
+  const char*     language = sord_node_get_language(node);
   if (datatype) {
     const char* type_uri = (const char*)sord_node_get_string(datatype);
     if (!strcmp(type_uri, (const char*)NS_XSD "int") ||
@@ -801,7 +804,9 @@ read_node(Sratom*         sratom,
 
       SerdNode rel =
         serd_node_new_relative_uri(&uri, &sratom->base, &sratom->base, NULL);
-      uint8_t* path = serd_file_uri_parse(rel.buf, NULL);
+
+      uint8_t* const path = serd_file_uri_parse((const uint8_t*)rel.buf, NULL);
+
       if (path) {
         lv2_atom_forge_path(
           forge, (const char*)path, strlen((const char*)path));
@@ -871,7 +876,7 @@ sratom_forge_sink(LV2_Atom_Forge_Sink_Handle handle,
 LV2_Atom*
 sratom_forge_deref(LV2_Atom_Forge_Sink_Handle handle, LV2_Atom_Forge_Ref ref)
 {
-  SerdChunk* chunk = (SerdChunk*)handle;
+  const SerdChunk* chunk = (const SerdChunk*)handle;
   return (LV2_Atom*)(chunk->buf + ref - 1);
 }
 
@@ -891,12 +896,12 @@ sratom_from_turtle(Sratom*         sratom,
   SerdReader* reader = sord_new_reader(model, env, SERD_TURTLE, NULL);
 
   if (!serd_reader_read_string(reader, (const uint8_t*)str)) {
-    SordNode* s = sord_node_from_serd_node(world, env, subject, 0, 0);
+    const SordNode* s = sord_node_from_serd_node(world, env, subject, 0, 0);
     lv2_atom_forge_set_sink(
       &sratom->forge, sratom_forge_sink, sratom_forge_deref, &out);
     if (subject && predicate) {
-      SordNode* p = sord_node_from_serd_node(world, env, predicate, 0, 0);
-      SordNode* o = sord_get(model, s, p, NULL, NULL);
+      const SordNode* p = sord_node_from_serd_node(world, env, predicate, 0, 0);
+      SordNode*       o = sord_get(model, s, p, NULL, NULL);
       if (o) {
         sratom_read(sratom, &sratom->forge, world, model, o);
         sord_node_free(world, o);
